glue\_genes.glue\_genomics\_data.bigwig\_factory.read\_bigwig
=============================================================

.. currentmodule:: glue_genes.glue_genomics_data.bigwig_factory

.. autofunction:: read_bigwig